layout

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ScreenPlacement added in v0.1.0

type ScreenPlacement struct {
	Row    int    // absolute terminal row (1-based)
	Col    int    // absolute terminal col (1-based)
	Escape string // kitty graphics escape sequence
}

ScreenPlacement is an image placement with absolute screen coordinates.

func Render

func Render(modules []module.Module, columns, termWidth, termHeight int) (string, []ScreenPlacement)

Render arranges modules into a columnar grid. It returns the rendered text and any image placements with absolute positions.

Jump to